@@ -9,10 +9,13 @@
 #' @export
 #'
 #' @examples
-#' t0 <- trajectory() %>% timeout(0)
-#' env <- simmer(verbose=TRUE) %>%
+#' t0 <- trajectory() %>%
+#'   timeout(0)
+#'
+#' simmer() %>%
 #'   add_generator("dummy", t0, at(0, c(1,10,30), 40, 43)) %>%
-#'   run(100)
+#'   run(100) %>%
+#'   get_mon_arrivals()
 at <- function(...) {
   time_vec <- c(...)
   time_diffs <- c(time_vec[1], diff(time_vec))
@@ -36,10 +39,13 @@ at <- function(...) {
 #' @export
 #'
 #' @examples
-#' t0 <- trajectory() %>% timeout(0)
-#' env <- simmer(verbose=TRUE) %>%
+#' t0 <- trajectory() %>%
+#'   timeout(0)
+#'
+#' simmer() %>%
 #'   add_generator("dummy", t0, from(5, function() runif(1, 1, 2))) %>%
-#'   run(10)
+#'   run(10) %>%
+#'   get_mon_arrivals()
 from <- function(start_time, dist, arrive=TRUE) {
   started <- FALSE
   function() {
@@ -68,10 +74,13 @@ from <- function(start_time, dist, arrive=TRUE) {
 #' @export
 #'
 #' @examples
-#' t0 <- trajectory() %>% timeout(0)
-#' env <- simmer(verbose=TRUE) %>%
+#' t0 <- trajectory() %>%
+#'   timeout(0)
+#'
+#' simmer() %>%
 #'   add_generator("dummy", t0, to(5, function() runif(1, 1, 2))) %>%
-#'   run(10)
+#'   run(10) %>%
+#'   get_mon_arrivals()
 to <- function(stop_time, dist) {
   counter <- 0
   function() {
@@ -90,35 +99,52 @@ to <- function(stop_time, dist) {
 #'
 #' @inheritParams from
 #' @inheritParams to
+#' @param every repeat with this time cycle.
 #'
 #' @return Returns a generator function.
 #' @seealso \code{\link{add_generator}}.
 #' @export
 #'
 #' @examples
-#' t0 <- trajectory() %>% timeout(0)
-#' env <- simmer(verbose=TRUE) %>%
-#'   add_generator("dummy", t0, from_to(5, 10, function() runif(1, 1, 2))) %>%
-#'   run(100)
-from_to <- function(start_time, stop_time, dist, arrive=TRUE){
+#' t0 <- trajectory() %>%
+#'   timeout(0)
+#'
+#' # from 8 to 16 h every 24 h:
+#' simmer() %>%
+#'   add_generator("dummy", t0, from_to(8, 16, function() runif(1, 1, 2), every=24)) %>%
+#'   run(48) %>%
+#'   get_mon_arrivals()
+from_to <- function(start_time, stop_time, dist, arrive=TRUE, every=NULL) {
+  stopifnot(is.null(every) || every >= stop_time)
   started <- FALSE
+  init <- 0
   counter <- 0
   function() {
-    if (!started) {
-      started <<- TRUE
-      if (arrive) {
-        dt <- start_time
+    while (TRUE){
+      if (!started) {
+        started <<- TRUE
+        if (arrive) {
+          dt <- start_time - init
+        } else {
+          dt <- dist()
+          dt[1] <- dt[1] + start_time - init
+        }
       } else {
         dt <- dist()
-        dt[1] <- dt[1] + start_time
       }
-    } else {
-      dt <- dist()
+      len <- length(dt)
+      dt <- dt[cumsum(dt) + counter < stop_time]
+      counter <<- counter + sum(dt)
+      if (len == length(dt))
+        return(dt)
+      if (is.null(every))
+        return(c(dt, -1))
+      if (length(dt))
+        return(dt)
+      start_time <<- start_time + every
+      stop_time <<- stop_time + every
+      started <<- FALSE
+      init <<- counter
     }
-    len <- length(dt)
-    dt <- dt[cumsum(dt) + counter < stop_time]
-    counter <<- counter + sum(dt)
-    if (len == length(dt)) return(dt)
-    return(c(dt, -1))
   }
 }
