@@ -3,15 +3,16 @@
 }
 
 evaluate_value <- function(value) {
-  tryCatch({
-      abs(eval(parse(text = value)))
-    },
-    error = function(err) value)
+  value <- magrittr_workaround(value)
+  if (is.null(value) || is.function(value)) value
+  else tryCatch({
+    sapply(value, function(i) abs(eval(parse(text = i))))
+  }, error = function(err) value)
 }
 
 needs_attrs <- function(variable) {
   if (is.function(variable))
-    return(length(methods::formalArgs(variable)))
+    return(length(formals(variable)))
   else return(0)
 }
 
@@ -28,6 +29,9 @@ envs_apply <- function(envs, method, ...) {
 }
 
 make_resetable <- function(distribution) {
+  distribution <- magrittr_workaround(distribution)
+  if (identical(environment(distribution), .GlobalEnv))
+    environment(distribution) <- new.env(parent = environment(distribution))
   init <- as.list(environment(distribution))
   environment(distribution)$.reset <- new.env(parent = environment(distribution))
   environment(distribution)$.reset$init <- init
@@ -39,3 +43,16 @@ make_resetable <- function(distribution) {
   environment(environment(distribution)$.reset$reset) <- environment(distribution)$.reset
   return(distribution)
 }
+
+binarise <- function(...) {
+  args <- c(...)
+  sum(2^(seq_along(args) - 1) * args) + 1
+}
+
+# see https://github.com/tidyverse/magrittr/issues/146
+magrittr_workaround <- function(func) {
+  if (is.function(func) && !identical(environment(func), .GlobalEnv) &&
+      "." %in% ls(envir=environment(func), all.names=TRUE))
+    rm(".", envir=environment(func))
+  func
+}
